@@ -2,16 +2,17 @@
 
 use std::fmt::{self, Debug};
 
-use crate::error::Error;
-
 #[cfg(feature = "use_glib")]
 use glib::translate::*;
 
+use crate::Error;
+
 // Helper macro for our GValue related trait impls
 #[cfg(feature = "use_glib")]
 macro_rules! gvalue_impl {
     ($name:ty, $get_type:expr) => {
         impl glib::types::StaticType for $name {
+            #[inline]
             fn static_type() -> glib::Type {
                 unsafe { from_glib($get_type()) }
             }
@@ -42,6 +43,13 @@ macro_rules! gvalue_impl {
                 <Self as glib::StaticType>::static_type()
             }
         }
+
+        impl From<$name> for glib::Value {
+            #[inline]
+            fn from(v: $name) -> Self {
+                glib::value::ToValue::to_value(&v)
+            }
+        }
     };
 }
 
@@ -1969,7 +1977,7 @@ impl fmt::Display for MeshCorner {
 }
 
 #[cfg(any(feature = "freetype", feature = "dox"))]
-#[derive(Clone, PartialEq, PartialOrd, Debug, Copy)]
+#[derive(Clone, PartialEq, Eq, PartialOrd, Ord, Debug, Copy)]
 #[non_exhaustive]
 #[doc(alias = "cairo_ft_synthesize_t")]
 pub enum FtSynthesize {
@@ -2021,7 +2029,7 @@ impl fmt::Display for FtSynthesize {
 }
 
 #[cfg(any(feature = "script", feature = "dox"))]
-#[derive(Clone, PartialEq, PartialOrd, Debug, Copy)]
+#[derive(Clone, PartialEq, Eq, PartialOrd, Ord, Debug, Copy)]
 #[non_exhaustive]
 #[doc(alias = "cairo_script_mode_t")]
 pub enum ScriptMode {
